/// <reference types="node" />
import { processCommands } from './utils';
import DeviceNetworking from './device-networking';
export declare type MethodResponse = {
    children?: {
        id: string;
    }[];
};
export declare type CommonSysinfo = {
    alias: string;
    deviceId: string;
    model: string;
    sw_ver: string;
    hw_ver: string;
};
declare type SysinfoChildren = {
    children?: [{
        id: string;
        alias: string;
        state: number;
    }];
};
export declare type PlugSysinfo = CommonSysinfo & SysinfoChildren & ({
    type: 'IOT.SMARTPLUGSWITCH' | 'IOT.RANGEEXTENDER.SMARTPLUG';
} | {
    mic_type: 'IOT.SMARTPLUGSWITCH';
}) & ({
    mac: string;
} | {
    ethernet_mac: string;
}) & {
    feature: string;
    led_off: 0 | 1;
    relay_state?: 0 | 1;
    dev_name?: string;
    brightness?: number;
};
declare type BulbSysinfoLightState = {
    on_off: 0 | 1;
};
export declare type BulbSysinfo = CommonSysinfo & {
    mic_type: string;
    mic_mac: string;
    description: string;
    light_state: BulbSysinfoLightState;
    is_dimmable: 0 | 1;
    is_color: 0 | 1;
    is_variable_color_temp: 0 | 1;
};
interface DeviceType {
    endSocketAfterResponse?: boolean;
}
declare type ApiType = {
    system: {
        get_sysinfo: () => PlugSysinfo | BulbSysinfo;
    };
};
declare type DataType = {
    alias?: string;
    model: string;
    mac: string;
    system: {
        sysinfo: PlugSysinfo | BulbSysinfo;
    };
};
declare class Device implements DeviceType {
    #private;
    static models: string[];
    api: ApiType;
    data: DataType;
    deviceNetworking: DeviceNetworking;
    endSocketAfterResponse?: boolean;
    model: string;
    unreliablePercent: number;
    constructor({ model, port, address, alias, responseDelay, unreliablePercent, data, }: {
        model: string;
        port?: number;
        address?: string;
        alias?: string;
        responseDelay?: number;
        unreliablePercent?: number;
        data?: Partial<DataType>;
    });
    get address(): string;
    get port(): number;
    start(): Promise<DeviceNetworking>;
    stop(): Promise<DeviceNetworking>;
    get children(): {
        sysinfo: {
            id: string;
        };
    }[];
    processMessage(msg: Buffer | string, encryptFn: (arg: string) => Buffer, customizerFn?: (moduleName: string, methodName: string, methodResponse: MethodResponse) => MethodResponse): {
        response: Buffer;
        responseForLog: string | Buffer;
    };
    processUdpMessage(msg: Buffer | string): {
        response: Buffer;
        responseForLog: string | Buffer;
    };
    processTcpMessage(msg: Buffer | string): {
        response: Buffer;
        responseForLog: string | Buffer;
    };
}
export { Device, processCommands };
//# sourceMappingURL=device.d.ts.map