"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _Device_deviceInfo;
Object.defineProperty(exports, "__esModule", { value: true });
exports.processCommands = exports.Device = void 0;
const tplink_smarthome_crypto_1 = require("tplink-smarthome-crypto");
const utils_1 = require("./utils");
Object.defineProperty(exports, "processCommands", { enumerable: true, get: function () { return utils_1.processCommands; } });
const device_networking_1 = __importDefault(require("./device-networking"));
class Device {
    constructor({ model, port = 0, address = '0.0.0.0', alias, responseDelay = 0, unreliablePercent = 0, data = {}, }) {
        this.unreliablePercent = 0;
        _Device_deviceInfo.set(this, void 0);
        this.deviceNetworking = new device_networking_1.default({
            device: this,
            model,
            port,
            address,
            responseDelay,
        });
        this.model = model;
        const buildableData = { ...data };
        buildableData.model = model;
        if (alias != null)
            buildableData.alias = alias;
        // eslint-disable-next-line global-require, import/no-dynamic-require, @typescript-eslint/no-var-requires
        const SpecificDevice = require(`./devices/${model}`);
        __classPrivateFieldSet(this, _Device_deviceInfo, new SpecificDevice(buildableData), "f");
        __classPrivateFieldGet(this, _Device_deviceInfo, "f").initDefaults();
        this.api = __classPrivateFieldGet(this, _Device_deviceInfo, "f").api;
        this.data = __classPrivateFieldGet(this, _Device_deviceInfo, "f").data;
        this.unreliablePercent = unreliablePercent;
    }
    get address() {
        return this.deviceNetworking.address;
    }
    get port() {
        return this.deviceNetworking.port;
    }
    async start() {
        return this.deviceNetworking.start();
    }
    async stop() {
        return this.deviceNetworking.stop();
    }
    get children() {
        return __classPrivateFieldGet(this, _Device_deviceInfo, "f").children;
    }
    processMessage(msg, encryptFn, customizerFn) {
        __classPrivateFieldGet(this, _Device_deviceInfo, "f").reset();
        let responseUnencrypted = (0, utils_1.processCommands)(msg, this.api, __classPrivateFieldGet(this, _Device_deviceInfo, "f").constructor.errors, customizerFn);
        let response = encryptFn(responseUnencrypted);
        const badData = (0, utils_1.unreliableData)(this.unreliablePercent);
        if (badData !== undefined) {
            responseUnencrypted = badData;
            response = badData;
        }
        return { response, responseForLog: responseUnencrypted };
    }
    processUdpMessage(msg) {
        return this.processMessage(msg, tplink_smarthome_crypto_1.encrypt, (moduleName, methodName, methodResponse) => {
            // UDP only returns last two characters of child.id
            if (moduleName === 'system' &&
                methodName === 'get_sysinfo' &&
                methodResponse &&
                methodResponse.children &&
                methodResponse.children.length > 0) {
                methodResponse.children.forEach((child) => {
                    // eslint-disable-next-line no-param-reassign
                    child.id = child.id.slice(-2);
                });
            }
            return methodResponse;
        });
    }
    processTcpMessage(msg) {
        return this.processMessage(msg, tplink_smarthome_crypto_1.encryptWithHeader);
    }
}
exports.Device = Device;
_Device_deviceInfo = new WeakMap();
Device.models = [
    'hs100',
    'hs105',
    'hs110',
    'hs110v2',
    'hs200',
    'hs220',
    'hs300',
    'lb100',
    'lb120',
    'lb130',
];
//# sourceMappingURL=device.js.map