"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = __importDefault(require("events"));
const dgram_1 = __importDefault(require("dgram"));
const debug_1 = __importDefault(require("debug"));
const log = (0, debug_1.default)('udp-server');
const logErr = (0, debug_1.default)('udp-server:error');
const Emitter = new events_1.default();
Emitter.setMaxListeners(25);
const UdpServer = Object.assign(Emitter, {
    socketBound: false,
    socket: undefined,
    start: function start({ port = 9999 } = {}) {
        const self = UdpServer;
        return new Promise((resolve, reject) => {
            try {
                const socket = dgram_1.default.createSocket({ type: 'udp4', reuseAddr: true });
                self.socket = socket;
                socket.on('listening', () => {
                    const address = socket.address();
                    self.socketBound = true;
                    log('UDP server listening', address);
                    resolve(UdpServer);
                });
                socket.on('message', (msg, rinfo) => {
                    self.emit('message', msg, rinfo);
                });
                socket.on('error', (exception) => {
                    logErr(exception);
                    socket.close();
                    self.socketBound = false;
                    reject(exception);
                });
                socket.bind(port);
            }
            catch (err) {
                reject(err);
            }
        });
    },
    stop: function stop() {
        const self = UdpServer;
        if (self.socketBound) {
            if (self.socket != null)
                self.socket.close();
            self.socketBound = false;
        }
    },
});
exports.default = UdpServer;
//# sourceMappingURL=udp-server.js.map