export function errCode(fn: any): (...args: any[]) => any;
export function randomMac(prefix: any, delimiter?: string): any;
export function generateId(len: any): string;
export function parseJsonStream(json: any): any[];
/**
 *
 * Commands appear to be processed in order with the exception of "context.child_ids" which is handled specially.
 *
 * - When multiple duplicate commands are sent, the last command "wins":
 *   `{"system":{"set_relay_state":{"state":0}},"system":{"set_relay_state":{"state":1}}}`
 *   will turn on the relay
 * - If multiple "context" modules are specified, the first is processed and not displayed in the output, the remaining items return an error:
 *   `"context":{"err_code":-1,"err_msg":"module not support"}`
 * - Devices that do not have multiple children will still silently ignore the first context found and all methods will still work
 * - Some methods support multiple child_ids (`set_relay_state`), some only act on the first child_id (`set_dev_alias`)
 * - `context:{}` or `context:[]` or `context:{"something_unexpected":[]}` has no effect, behaves as if no `context` was given (if first occurrence).
 * - `context:""` crashes my device!
 * - `context:{child_ids:{}}` or `context:{child_ids:[1]` will return `{ err_code: -3, err_msg: 'invalid argument' }` for commands that support child_id, but other commands will run as normal.
 * - `context:{child_ids:[]}` will run commands that support child_id but they will have no effect (applied to zero children).
 * - `context:{child_ids:["A"]}` will return `{ err_code: -14, err_msg: 'entry not exist' }` for commands that support child_id, but other commands will run as normal.
 * - if any of the `child_ids` are invalid or don't exist commands that support `child_ids` will not run the valid ones and will return an `err_code`
 *
 * @param {string|Buffer} json
 * @param {Object} api
 * @param {Function} [customizerFn]
 * @returns {string}
 */
export function processCommands(json: string | Buffer, api: Object, errors: any, customizerFn?: Function | undefined): string;
export function randomInt(min: any, max: any): number;
export function randomFloat(min: any, max: any): any;
export function randomLatitude({ fixed, min, max }?: {
    fixed?: number | undefined;
    min?: number | undefined;
    max?: number | undefined;
}): any;
export function randomLongitude({ fixed, min, max }?: {
    fixed?: number | undefined;
    min?: number | undefined;
    max?: number | undefined;
}): any;
export function getDayList(year: any, month: any, key: any, dayListData?: any[], defaultValue?: undefined): any[];
export function getMonthList(year: any, key: any, dayListData?: any[], defaultValue?: undefined): {
    [x: number]: any;
    year: any;
    month: number;
}[];
export function editRule(rules: any, rule: any): void;
export function deleteRule(rules: any, id: any): void;
export function readJson(path: any): Promise<any>;
export function unreliableData(unreliablePercent: any): Buffer | undefined;
//# sourceMappingURL=utils.d.ts.map